summaryrefslogtreecommitdiffstats
path: root/juk/playlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/playlist.h')
-rw-r--r--juk/playlist.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/juk/playlist.h b/juk/playlist.h
index aa1e1d84..d9273834 100644
--- a/juk/playlist.h
+++ b/juk/playlist.h
@@ -46,13 +46,14 @@ typedef TQValueList<PlaylistItem *> PlaylistItemList;
class Playlist : public KListView, public PlaylistInterface
{
Q_OBJECT
+ TQ_OBJECT
public:
- Playlist(PlaylistCollection *collection, const TQString &name = TQString::null,
+ Playlist(PlaylistCollection *collection, const TQString &name = TQString(),
const TQString &iconName = "midi");
Playlist(PlaylistCollection *collection, const PlaylistItemList &items,
- const TQString &name = TQString::null, const TQString &iconName = "midi");
+ const TQString &name = TQString(), const TQString &iconName = "midi");
Playlist(PlaylistCollection *collection, const TQFileInfo &playlistFile,
const TQString &iconName = "midi");
@@ -192,7 +193,7 @@ public:
/**
* Returns the file name associated with this playlist (an m3u file) or
- * TQString::null if no such file exists.
+ * TQString() if no such file exists.
*/
TQString fileName() const { return m_fileName; }
@@ -419,7 +420,7 @@ protected:
virtual bool eventFilter(TQObject *watched, TQEvent *e);
virtual void keyPressEvent(TQKeyEvent *e);
- virtual TQDragObject *dragObject(TQWidget *parent);
+ virtual TQDragObject *dragObject(TQWidget *tqparent);
virtual TQDragObject *dragObject() { return dragObject(this); }
virtual bool canDecode(TQMimeSource *s);
virtual void decode(TQMimeSource *s, PlaylistItem *item = 0);
@@ -434,7 +435,7 @@ protected:
virtual void insertItem(TQListViewItem *item);
virtual void takeItem(TQListViewItem *item);
- virtual bool hasItem(const TQString &file) const { return m_members.contains(file); }
+ virtual bool hasItem(const TQString &file) const { return m_members.tqcontains(file); }
void addColumn(const TQString &label);
@@ -456,7 +457,7 @@ protected:
void setupItem(PlaylistItem *item);
/**
* Forwards the call to the parent to enable or disable automatic deletion
* of tree view playlists. Used by CollectionListItem.
*/
void setDynamicListsFrozen(bool frozen);
@@ -711,7 +712,7 @@ private:
bool processEvents();
-class FocusUpEvent : public QCustomEvent
+class FocusUpEvent : public TQCustomEvent
{
public:
FocusUpEvent() : TQCustomEvent(id) {}
@@ -456,7 +457,7 @@ protected:
void setupItem(PlaylistItem *item);
/**
- * Forwards the call to the parent to enable or disable automatic deletion
+ * Forwards the call to the tqparent to enable or disable automatic deletion
* of tree view playlists. Used by CollectionListItem.
*/